Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddtoConfig ¶
func AddtoConfig(auth *Player)
AddtoConfig is used to update the config file with a provided profile
func Checkrealms ¶
Checkrealms can get IP of the realm so that you can login in realms
func Directlogin ¶
Directlogin is used to load config and login according to the uuid
func LoadConfiglogin ¶
func LoadConfiglogin(auth *Player)
LoadConfiglogin can load config and ask you to choose a profile and login
Types ¶
Click to show internal directories.
Click to hide internal directories.